Datatree
========

**Datatree is a prototype implementation of a tree-like hierarchical data structure for xarray.**


.. toctree::
   :maxdepth: 2
   :caption: Documentation Contents

   Installation <installation>
   Quick Overview <quick-overview>
   Tutorial <tutorial>
   Data Model <data-structures>
   Reading and Writing Files <io>
   API Reference <api>
   How do I ... <howdoi>
   Contributing Guide <contributing>
   Development Roadmap <roadmap>
   What's New <whats-new>
   GitHub repository <https://github.com/xarray-contrib/datatree>

Feedback
--------

If you encounter any errors, problems with **Datatree**, or have any suggestions, please open an issue
on `GitHub <http://github.com/xarray-contrib/datatree>`_.
